@@ -119,7 +119,10 @@ class DatabaseCreation(BaseDatabaseCreation):
             if all(map(lambda v: v[:2] != django_version, versions)):
                 continue
             test_case_name, _, method_name = test_name.rpartition('.')
-            test_case = import_string(test_case_name)
+            try:
+                test_case = import_string(test_case_name)
+            except:
+                continue
             method = getattr(test_case, method_name)
             method = expectedFailure(method)
             setattr(test_case, method_name, method)
@@ -160,13 +163,16 @@ class DatabaseCreation(BaseDatabaseCreation):
         for alias in connections:
             connections[alias].close()
         try:
-            with self._nodb_connection.cursor() as cursor:
+            cursor = self._nodb_connection.cursor()
+            try:
                 qn_db_name = self.connection.ops.quote_name(test_database_name)
                 # boot all other connections to the database, leaving only this connection
                 cursor.execute("ALTER DATABASE %s SET SINGLE_USER WITH ROLLBACK IMMEDIATE" % qn_db_name)
                 time.sleep(1)
                 # database is now clear to drop
                 cursor.execute("DROP DATABASE %s" % qn_db_name)
+            finally:
+                cursor.close()
         except Exception as e:
             # if 'it is currently in use' in str(e):
             #     six.print_('Cannot drop database %s because it is in use' % test_database_name)
@@ -269,9 +275,12 @@ EXTERNAL NAME regex_clr.UserDefinedFunctions.REGEXP_LIKE
             assembly_hex=self.get_regex_clr_assembly_hex(),
         ).split(';')
 
-        with self._nodb_connection.cursor() as cursor:
+        cursor = self._nodb_connection.cursor()
+        try:
             for s in sql:
                 cursor.execute(s)
+        finally:
+            cursor.close()
 
     def get_regex_clr_assembly_hex(self):
         import os
